[Pkg-mozext-commits] [firebug] 19/59: Fixed the console hiding to mimic the way panel toolbar was handled.

David Prévot taffit at moszumanska.debian.org
Thu Aug 14 14:52:54 UTC 2014


This is an automated email from the git hooks/post-receive script.

taffit pushed a commit to branch master
in repository firebug.

commit cc3264a9126f11f7f605ccb59be41c8abd28f063
Author: Michael Caputo <therubikscubekid at gmail.com>
Date:   Sun Jul 27 17:48:37 2014 -0400

    Fixed the console hiding to mimic the way panel toolbar was handled.
---
 extension/content/firebug/chrome/panelActivation.js | 6 ++----
 1 file changed, 2 insertions(+), 4 deletions(-)

diff --git a/extension/content/firebug/chrome/panelActivation.js b/extension/content/firebug/chrome/panelActivation.js
index 19de713..b10af1b 100644
--- a/extension/content/firebug/chrome/panelActivation.js
+++ b/extension/content/firebug/chrome/panelActivation.js
@@ -79,11 +79,9 @@ Firebug.PanelActivation = Obj.extend(Module,
         // the 'fbToolbox', so there is no line below the panel tab.
         Dom.collapse(Firebug.chrome.$("fbToolbox"), !panel);
 
 	// Search box is not displayed for disabled panels.
 	var searchBox = Firebug.chrome.$("fbSearchBox");
-	searchBox.collapsed = !panel;
-	
-	
+	Dom.collapse(searchBox, !panel);
     },
 
     // * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
@@ -79,11 +79,9 @@ Firebug.PanelActivation = Obj.extend(Module,
         Dom.collapse(Firebug.chrome.$("fbToolbox"), !panel);
 
-	// Search box is not displayed for disabled panels.
+	// Search box is not displayed for disabled panels. Collapse the element.
 	var searchBox = Firebug.chrome.$("fbSearchBox");

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-mozext/firebug.git



More information about the Pkg-mozext-commits mailing list